@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,7 +26,7 @@ class GravatarConfigWidgetTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit GravatarConfigWidgetTest(QObject *parent = Q_NULLPTR);
+    explicit GravatarConfigWidgetTest(QObject *parent = nullptr);
     ~GravatarConfigWidgetTest();
 
 private Q_SLOTS:
