@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -34,11 +34,9 @@ public:
 
     QPixmap gravatarPixmap() const;
 
-private Q_SLOTS:
-    void slotAccepted();
-
 private:
-    Gravatar::GravatarDownloadPixmapWidget *mGravatarDownloadPixmapWidget;
+    void slotAccepted();
+    Gravatar::GravatarDownloadPixmapWidget *mGravatarDownloadPixmapWidget = nullptr;
 };
 }
 
